@@ -76,31 +76,37 @@ class MythbuntuBaRePlugin(MCCPlugin):
            and stores it into the plugin's own internal structures"""
         import os
         self.changes = {}
-        if os.path.exists(self.CONFIGFILE):
-          try:
-            self.config.read(self.CONFIGFILE)
-            self.changes['serverip'] = self.config.get("General", "serverip")
-            self.changes['managed'] = self.config.get("General", "managed")
-            if str.lower(self.changes['managed']) == "true":
-              self.managed_label.set_text("This machine is current in managed mode")
-              self.radio_convert.set_sensitive(False)
-              self.backup_schedule.set_sensitive(False)
-            self.changes['BackupLocation'] = self.config.get("Backup", "storagedir")
-            self.changes['backup_db'] = self.config.get("Backup", "db")
-            self.changes['backup_schedule'] = self.config.get("Backup", "schedule")
-            self.changes['backup_schedule_day'] = self.config.get("Backup", "day")
-            self.changes['backup_schedule_hour'] = self.config.get("Backup", "hour")
-            self.changes['backup_schedule_minute'] = self.config.get("Backup", "minute")
-            self.changes['backup_schedule_weekday'] = self.config.get("Backup", "weekday")
-            self.db_backup_checkbutton.set_active(int(self.config.get("Backup", "db")))
-          except:
-            print "Error: Could not read config file"
-          if not self.query_installed('mythtv-backend-master'):
-            self.backup_db_label.set_text("Database can only be backed up from master backend")
-            self.db_backup_checkbutton.set_sensitive(False)
-            self.db_backup_checkbutton.set_active(False)
-        else:
-          print "Error: Config file not found"
+        try:
+          self.config.read(self.CONFIGFILE)
+          self.changes['serverip'] = self.config.get("General", "serverip")
+          self.changes['managed'] = self.config.get("General", "managed")
+          if str.lower(self.changes['managed']) == "true":
+            self.managed_label.set_text("This machine is current in managed mode")
+            self.radio_convert.set_sensitive(False)
+            self.backup_schedule.set_sensitive(False)
+          self.changes['BackupLocation'] = self.config.get("Backup", "storagedir")
+          self.changes['backup_db'] = self.config.get("Backup", "db")
+          self.changes['backup_schedule'] = self.config.get("Backup", "schedule")
+          self.changes['backup_schedule_day'] = self.config.get("Backup", "day")
+          self.changes['backup_schedule_hour'] = self.config.get("Backup", "hour")
+          self.changes['backup_schedule_minute'] = self.config.get("Backup", "minute")
+          self.changes['backup_schedule_weekday'] = self.config.get("Backup", "weekday")
+          self.db_backup_checkbutton.set_active(int(self.config.get("Backup", "db")))
+        except:
+          print "Error: Config file not found. Setting defaults"
+          self.changes['serverip'] = "127.0.0.1"
+          self.changes['managed'] = "False"
+          self.changes['BackupLocation'] = "/var/lib/mythtv/bare/"
+          self.changes['backup_db'] = False
+          self.changes['backup_schedule'] = "disabled"
+          self.changes['backup_schedule_day'] = "*"
+          self.changes['backup_schedule_hour'] = "0"
+          self.changes['backup_schedule_minute'] = "00"
+          self.changes['backup_schedule_weekday'] = "*"
+        if not self.query_installed('mythtv-backend-master'):
+          self.backup_db_label.set_text("Database can only be backed up from master backend")
+          self.db_backup_checkbutton.set_sensitive(False)
+          self.db_backup_checkbutton.set_active(False)
 
     def applyStateToGUI(self):
         """Takes the current state information and sets the GUI
@@ -317,7 +323,11 @@ class MythbuntuBaRePlugin(MCCPlugin):
               self.tab_history.append(self.CUR_TAB)
               self.CUR_TAB = "vbox_backup_location"
               self.vbox_backup_location.show()
-#              self.next_button.set_sensitive(False)
+            elif self.schedule_disabled_button.get_active():
+              self.tab_history.append(self.CUR_TAB)
+              self.CUR_TAB = "vbox_final"
+              self.vbox_final.show()
+              self.next_button.set_sensitive(False)
         elif self.CUR_TAB == "vbox_managed_convert":
             if self.ValidNewConf == True:
                 self.tab_history.append(self.CUR_TAB)
